@@ -114,6 +114,13 @@ connection object stays alive as long as you are using it, like that:
     cur.close()  # or del cur
     db.close()  # or del db
 
+You can also use context managers for simpler code:
+
+    with pool.connection() as db:
+        with db.cursor as cur:
+            cur.execute(...)
+            res = cur.fetchone()
+
 Note that you need to explicitly start transactions by calling the
 begin() method.  This ensures that the connection will not be shared
 with other threads, that the transparent reopening will be suspended
@@ -277,8 +284,7 @@ class PooledDB:
         then the connection may be shared with other threads.
         """
         if shareable and self._maxshared:
-            self._lock.acquire()
-            try:
+            with self._lock:
                 while (not self._shared_cache and self._maxconnections
                         and self._connections >= self._maxconnections):
                     self._wait_lock()
@@ -306,12 +312,9 @@ class PooledDB:
                 # put the connection (back) into the shared cache
                 self._shared_cache.append(con)
                 self._lock.notify()
-            finally:
-                self._lock.release()
             con = PooledSharedDBConnection(self, con)
         else:  # try to get a dedicated connection
-            self._lock.acquire()
-            try:
+            with self._lock:
                 while (self._maxconnections
                         and self._connections >= self._maxconnections):
                     self._wait_lock()
@@ -324,8 +327,6 @@ class PooledDB:
                     con._ping_check()  # check connection
                 con = PooledDedicatedDBConnection(self, con)
                 self._connections += 1
-            finally:
-                self._lock.release()
         return con
 
     def dedicated_connection(self):
@@ -334,8 +335,7 @@ class PooledDB:
 
     def unshare(self, con):
         """Decrease the share of a connection in the shared cache."""
-        self._lock.acquire()
-        try:
+        with self._lock:
             con.unshare()
             shared = con.shared
             if not shared:  # connection is idle,
@@ -343,15 +343,12 @@ class PooledDB:
                     self._shared_cache.remove(con)  # from shared cache
                 except ValueError:
                     pass  # pool has already been closed
-        finally:
-            self._lock.release()
         if not shared:  # connection has become idle,
             self.cache(con.con)  # so add it to the idle cache
 
     def cache(self, con):
         """Put a dedicated connection back into the idle cache."""
-        self._lock.acquire()
-        try:
+        with self._lock:
             if not self._maxcached or len(self._idle_cache) < self._maxcached:
                 con._reset(force=self._reset)  # rollback possible transaction
                 # the idle cache is not full, so put it there
@@ -360,13 +357,10 @@ class PooledDB:
                 con.close()  # then close the connection
             self._connections -= 1
             self._lock.notify()
-        finally:
-            self._lock.release()
 
     def close(self):
         """Close all connections in the pool."""
-        self._lock.acquire()
-        try:
+        with self._lock:
             while self._idle_cache:  # close all idle connections
                 con = self._idle_cache.pop(0)
                 try:
@@ -382,14 +376,12 @@ class PooledDB:
                         pass
                     self._connections -= 1
             self._lock.notifyAll()
-        finally:
-            self._lock.release()
 
     def __del__(self):
         """Delete the pool."""
         try:
             self.close()
-        except Exception:
+        except:  # builtin Exceptions might not exist any more
             pass
 
     def _wait_lock(self):
@@ -437,9 +429,17 @@ class PooledDedicatedDBConnection:
         """Delete the pooled connection."""
         try:
             self.close()
-        except Exception:
+        except:  # builtin Exceptions might not exist any more
             pass
 
+    def __enter__(self):
+        """Enter a runtime context for the connection."""
+        return self
+
+    def __exit__(self, *exc):
+        """Exit a runtime context for the connection."""
+        self.close()
+
 
 class SharedDBConnection:
     """Auxiliary class for shared connections."""
@@ -524,5 +524,13 @@ class PooledSharedDBConnection:
         """Delete the pooled connection."""
         try:
             self.close()
-        except Exception:
+        except:  # builtin Exceptions might not exist any more
             pass
+
+    def __enter__(self):
+        """Enter a runtime context for the connection."""
+        return self
+
+    def __exit__(self, *exc):
+        """Exit a runtime context for the connection."""
+        self.close()
