@@ -512,7 +512,7 @@ class SteadyDBConnection:
         """Delete the steady connection."""
         try:
             self._close()  # make sure the connection is closed
-        except Exception:
+        except:  # builtin Exceptions might not exist any more
             pass
 
 
@@ -697,5 +697,5 @@ class SteadyDBCursor:
         """Delete the steady cursor."""
         try:
             self.close()  # make sure the cursor is closed
-        except Exception:
+        except:  # builtin Exceptions might not exist any more
             pass
